/*
 * Copyright (c) 2022 - 2023, Nordic Semiconductor ASA
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef NPMX_CONFIG_H__
#define NPMX_CONFIG_H__

#if defined(NPM1300)
    #include <npmx_config_npm1300.h>
#else
    #error "Unknown device."
#endif

// VBUSIN current limit (in milliamperes)
// range 100, 500-1500
#ifndef CONFIG_CURRENT_LIMIT
    #define CONFIG_CURRENT_LIMIT 500
#endif

// Battery charging current (in milliamperes)
// Available range is 32 mA to 800 mA in 2 mA steps
// Must be not greater than CONFIG_CURRENT_LIMIT
#ifndef CONFIG_CHARGING_CURRENT
    #define CONFIG_CHARGING_CURRENT 300
#endif

// Battery discharge current limit (in milliamperes)
// Available range is 270 mA to 1340 mA in 3.23 mA steps
#ifndef CONFIG_DISCHARGING_CURRENT
    #define CONFIG_DISCHARGING_CURRENT 1000
#endif

// Battery termination voltage in normal temperature
// range 3500 4450
#ifndef CONFIG_TERMINATION_VOLTAGE_NORMAL
    #define CONFIG_TERMINATION_VOLTAGE_NORMAL 4200
#endif

// Battery termination voltage in warm temperature
// range 3500 4450
#ifndef CONFIG_TERMINATION_VOLTAGE_WARM
    #define CONFIG_TERMINATION_VOLTAGE_WARM 4000
#endif

// Thermistor nominal resistance in Ohms
// 10000, 47000, 100000
#ifndef CONFIG_THERMISTOR_RESISTANCE
    #define CONFIG_THERMISTOR_RESISTANCE 10000
#endif

// Battery termination voltage in warm temperature
// range 3500 4450
#ifndef CONFIG_THERMISTOR_BETA
    #define CONFIG_THERMISTOR_BETA 3380
#endif

#endif // NPMX_CONFIG_H__
